X’inhi l-OiRA? | OiRA

Temi

# X’inhi l-OiRA?

## Ġdid(a) għall-OiRA?

Din hija introduzzjoni qasira għall-valutazzjoni tar-riskji u kif l-OiRA tista’ tgħinek tiġġestiha.

## X’inhi valutazzjoni tar-riskji?

Il-valutazzjoni tar-riskji hija l-bażi għall-ġestjoni b’suċċess tas-saħħa u s-sigurtà, u ċ-ċavetta għat-tnaqqis ta’ aċċidenti relatati max-xogħol u mard okkupazzjonali. Jekk tiġi implimentata sewwa, hija tista’ ttejjeb is-saħħa u s-sigurtà fuq il-post tax-xogħol - u l-prestazzjoni tan-negozju b’mod ġenerali.

Is-saħħa u s-sigurtà tal-ħaddiema huma protetti fl-Ewropa permezz tal-valutazzjoni u l-ġestjoni tar-riskji fuq il-post tax-xogħol. L-impjegaturi għandhom dmir legali li jiżguraw is-saħħa u s-sigurtà tal-ħaddiema f’kull aspett relatat max-xogħol u li jwettqu valutazzjoni tar-riskji. Għalhekk, kull kumpanija trid twettaq valutazzjoni tar-riskji u tfassal pjan ta’ azzjoni. Sabiex titwettaq valutazzjoni tar-riskji effettiva fuq il-post tax-xogħol, dawk kollha involuti jeħtieġu fehim ċar ta’:

- il-kuntest u l-kunċetti legali;
- il-proċess użat għall-valutazzjoni tar-riskji;
- ir-rwol li għandhom jaqdu l-atturi ewlenin involuti fil-proċess.

Il-ħaddiema u/jew ir-rappreżentanti tagħhom għandhom id-dritt li jiġu kkonsultati dwar arranġamenti biex iwettqu l-valutazzjoni tar-riskji u jipparteċipaw fiha.

Tista’ ssib aktar informazzjoni dwar il-valutazzjoni tar-riskji u l-parteċipazzjoni tal-ħaddiema u/jew tar-rappreżentanti tagħhom fil-proċess tal-valutazzjoni tar-riskji fuq is-sit web tal-proġett OiRA.

## X’inhi l-OiRA?

OiRA tfisser ‘Online Interactive Risk Assessment’ (Valutazzjoni tar-Riskji Interattiva Online). Hija applikazzjoni bbażata fuq l-internet li tippermettilek twettaq valutazzjoni tar-riskji tas-saħħa u tas-sigurtà tal-post tax-xogħol tiegħek.

## Għal min hija maħsuba l-OiRA?

L-OiRA tista’ tintuża minn kwalunkwe persuna biex tivvaluta r-riskji relatati mas-saħħa u s-sigurtà li jistgħu jeżistu fuq il-post tax-xogħol tagħha.

Madankollu, l-OiRA hija maħsuba biex tkun tal-akbar valur għal negozji iżgħar. L-OiRA ġiet żviluppata speċifikament biex tappoġġjahom fil-valutazzjoni tar-riskji fuq il-post tax-xogħol u tgħinhom jipproduċu valutazzjoni tar-riskji dokumentata, inkluż pjan ta’ azzjoni mfassal apposta għar-rekwiżiti tal-istabbiliment.

## X’għandi nagħmel?

Hemm diversi stadji li jridu jitlestew fil-proċess tal-valutazzjoni tar-riskji tal-OiRA:

- Preparazzjoni: xi għodod għandhom mistoqsijiet dwar il-profil li jgħinuk tfassal l-għodda skont il-karatteristiċi speċifiċi tal-istabbiliment tiegħek. Meta twieġeb il-mistoqsijiet dwar il-profil, l-għodda tadatta għas-sitwazzjoni speċifika tiegħek u turik il-moduli li japplikaw.

- Involviment: kull valutazzjoni tar-riskji għandha ssir bl-involviment attiv tal-ħaddiema. L-għodda tippermettilek tistampa t-test sħiħ tal-valutazzjoni tar-riskji, jew partijiet minnu, sabiex tinforma lill-ħaddiema u tikseb ir-rispons tagħhom.

- Identifikazzjoni tar-riskji: L-OiRA se tippreżenta serje ta’ perikli jew problemi potenzjali għas-saħħa u s-sigurtà li jistgħu jeżistu fuq il-post tax-xogħol tiegħek. Billi twieġeb id-dikjarazzjonijiet/il-mistoqsijiet b’iva jew le, tkun qed tiddikjara jekk dawn il-perikli jew il-problemi humiex preżenti. Tista’ tiddeċiedi wkoll li tħalli mistoqsija mhux imwieġba u mbagħad tweġibha fi stadju aktar tard.

- Evalwazzjoni: xi għodod jitolbuk tagħti prijorità lir-riskji li identifikajt. Hemm modi differenti kif tagħmel dan, li jiddependu mid-deċiżjonijiet meħuda mis-sħab nazzjonali/mill-iżviluppaturi tal-għodda tal-OiRA u l-approċċ speċifiku tagħhom. Xi għodod jipprijoritizzaw ukoll ir-riskji awtomatikament fl-isfond u inti tkun tista’ tħassar dawn il-prijoritajiet.

- Pjan ta’ azzjoni: għal kull riskju identifikat, l-għodda titolbok tiddeċiedi dwar miżura waħda jew aktar biex telimina jew tnaqqas ir-riskju. Ħafna mill-għodod jissuġġerulek xi miżuri. Dejjem tista’ tagħżel ukoll li ddaħħal il-miżuri tiegħek stess.

- Rapport: inti legalment meħtieġ tiddokumenta l-valutazzjoni tar-riskji tiegħek. Fit-taqsima tar-rapport, se ssib varjetà ta’ rapporti li jgħinuk iżżomm rekord tal-valutazzjoni tar-riskji tiegħek u ssegwi l-azzjonijiet/miżuri li tkun iddeċidejt li timplimenta biex telimina jew ittaffi r-riskji identifikati.

## Kemm iddum għaddejja?

Huwa impossibbli li tgħid kemm ġeneralment iddum għaddejja valutazzjoni, billi l-għodod ivarjaw skont is-settur u l-pajjiż.

Madankollu, tista’ tqatta’ kwalunkwe ħin li għandek disponibbli fuq valutazzjoni u mbagħad terġa’ lura għaliha meta jkun konvenjenti għalik u terġa’ taqbad mill-istess punt fejn tkun ħallejt.

## Għaliex għandi nirreġistra?

L-ewwel ħaġa li tintalab tagħmel meta tibda l-ewwel valutazzjoni tar-riskji tiegħek hija li toħloq kont tal-OiRA - dan huwa proċess sempliċi u rapidu.

Ir-reġistrazzjoni tippermettilek li sempliċiment tilloggja fi kwalunkwe ħin biex tkompli l-valutazzjonijiet preċedenti jew tibda oħrajn ġodda.

Jekk int utent irreġistrat, għandek ukoll l-għażla li tikseb valutazzjoni tar-riskji stampata, preċiża u aġġornata fi kwalunkwe ħin.

## Għandi bżonn nipprepara?

Ma għandek bżonn l-ebda tip ta’ preparazzjoni speċifika biex tibda tuża l-għodda; madankollu, għandek tieħu ftit ħin biex taħseb dwar min se jwettaq il-valutazzjoni tar-riskji u kif il-ħaddiema se jkunu involuti fil-proċess.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More